Hello World!

# Hello World!¶

Comments will be rendered as Markdown. The `+` and `-` below ensure that only one code cell is produced, even though the lines are not contiguous

In [1]:

    def freeze_warning(temp_c):
        """
        This demonstrates how larger blocks of code can be built compositionally.
        """
        if temp_c < 0:
            print("It is freezing!")

    freeze_warning(-10)

    It is freezing!